<?php
/**
 * Dribbble widget.
 *
 * @package    Silver
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Silver_Dribbble_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_ops = array(
			'classname'   => 'widget_flickr widget-dribbble row-2',
			'description' => esc_html__( 'Display your Dribbble feed.', 'silver' ),
			'customize_selective_refresh' => true,
		);

		// Create the widget.
		parent::__construct(
			'silver-dribbble',                          // $this->id_base
			esc_html__( '&raquo; Dribbble', 'silver' ), // $this->name
			$widget_ops                                 // $this->widget_options
		);

		$this->alt_option_name = 'widget_dribbble';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Social widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title = isset( $instance['title'] ) ? $instance['title'] : '';
		$token = isset( $instance['token'] ) ? esc_attr( $instance['token'] ) : '';
		$user  = isset( $instance['user'] ) ? esc_attr( $instance['user'] ) : '';
		$limit = isset( $instance['limit'] ) ? absint( $instance['limit'] ) : 9;

		// Output the theme's $before_widget wrapper.
		echo $args['before_widget'];

		// If the title not empty, display it.
		if ( $title ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $title, $instance, $this->id_base ) . $args['after_title'];
		}
		?>
			<div id="dribbble-shots"></div>

			<?php if ( $token ) : ?>
				<script>
					( function( $ ) {
						$( function() {
							$.jribbble.setToken( '<?php echo $token; ?>' );
							$.jribbble.users( '<?php echo $user; ?>' ).shots({per_page: <?php echo $limit; ?>}).then(function(shots) {
								var html = [];
								shots.forEach(function(shot) {
									html.push('<a href="' + shot.html_url + '" target="_blank">');
									html.push('<img src="' + shot.images.normal + '" class="widget-thumb">');
									html.push('</a>');
								});
								$('#dribbble-shots').html(html.join(''));
							});
						} );
					}( jQuery ) );
				</script>
			<?php endif; ?>
		<?php
		// Close the theme's widget wrapper.
		echo $args['after_widget'];

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance           = $old_instance;
		$instance['title']  = sanitize_text_field( $new_instance['title'] );
		$instance['token']  = sanitize_text_field( $new_instance['token'] );
		$instance['user']   = sanitize_text_field( $new_instance['user'] );
		$instance['limit']  = (int) $new_instance['limit'];
		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : esc_html__( 'Dribbble', 'silver' );
		$token = isset( $instance['token'] ) ? esc_attr( $instance['token'] ) : '';
		$user  = isset( $instance['user'] ) ? esc_attr( $instance['user'] ) : '';
		$limit = isset( $instance['limit'] ) ? absint( $instance['limit'] ) : 4;
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'silver' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'token' ); ?>">
				<?php esc_html_e( 'API Key', 'silver' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'token' ); ?>" name="<?php echo $this->get_field_name( 'token' ); ?>" value="<?php echo $token; ?>" />
			<small><?php printf( esc_html__( '%1$sRegister new API Key here%2$s', 'silver' ), '<a href="https://dribbble.com/account/applications/new" target="_blank">', '</a>' ) ?></small>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'user' ); ?>">
				<?php esc_html_e( 'Username', 'silver' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'user' ); ?>" name="<?php echo $this->get_field_name( 'user' ); ?>" value="<?php echo $user; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>">
				<?php esc_html_e( 'Number of shots to show', 'silver' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" type="number" step="1" min="0" value="<?php echo $limit; ?>" />
		</p>

	<?php

	}

}
